.card {
    margin-bottom: 1rem;
}
.card.is-important {
    border: 1px solid #ff3860;
}
.card.is-important .card-header a {
    color: #ff3860;
}
.card.is-unassigned {
    border: 1px solid #ffdb4a;
}
p.card-footer-item {
    display: block;
}
.is-smoke {
    background: whitesmoke;
}
.logo {
    font-family: FontAwesome;
    font-size: 1.2rem;
}
.logo .fa-bug {
    color: #00d1b2;
}
#navbar-toggle-state {
    display: none;
}
#navbar-toggle-state:checked ~ .navbar-menu {
    display: block;
}
.task-description a {
    word-break: break-all;
}
p.task-description {
    word-break: break-word;
}
